/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*   http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/

package org.apache.samza.sql.interfaces;

import org.apache.samza.sql.schema.SqlSchema;


/**
 * Samza SQL application uses {@link RelSchemaProvider} to get the relational schema corresponding to the system
 * and stream.
 */
public interface RelSchemaProvider {
  /**
   * Converts the schema to relational schema. It is possible that there can be multiple tables associated
   * within a single schema.
   * @return Relational schema corresponding to the system stream.
   */
  SqlSchema getSqlSchema();
}
